@@ -57,3 +57,27 @@ class FormValidationTestCase(TestCase):
             "Expected HTTP 200, but got HTTP %d. "
             "Looks like the form validated when it shouldn't." % status_code)
 
+
+class RedirectTestCase(TestCase):
+    def assertRedirectsTo(self, response, expected_url):
+        """Django's assertRedirects doesn't support external URLs, so we roll
+        our own here. Note that the test client can't fetch external
+        URLs, so we mustn't use fetch=True.
+
+        """
+        if response.status_code != 302:
+            self.fail("Did not redirect (got HTTP %s instead)." % response.status_code)
+
+        if hasattr(response, "redirect_chain"):
+            self.fail("You can't use assertRedirects with follow=True.")
+        
+        final_url = response._headers['location'][1]
+
+        if not expected_url.startswith('http://'):
+            # we were given a relative URL, so convert it
+            expected_url = "http://testserver%s" % expected_url
+
+        self.assertEqual(
+            final_url, expected_url,
+            "Expected to be redirected to %s, but got %s instead." % (expected_url, final_url)
+        )
